package ch.zhaw.projekt2.turnierverwaltung;

import ch.zhaw.projekt2.turnierverwaltung.main.gameScheduleView.GameController;
import ch.zhaw.projekt2.turnierverwaltung.main.gameScheduleView.GameDecorator;
import ch.zhaw.projekt2.turnierverwaltung.main.tournamentList.TournamentListController;
import javafx.fxml.FXMLLoader;
import javafx.scene.layout.BorderPane;
import javafx.scene.layout.VBox;

import java.io.IOException;
import java.net.URL;

public class Factory {
    private TournamentDecorator tournamentDecorator;
    private FileIO fileIO;

    public Factory(FileIO fileIO, TournamentDecorator tournamentDecorator){
        this.fileIO = fileIO;
        this.tournamentDecorator = tournamentDecorator;
    }

    public TournamentDecorator getTournamentDecorator() {
        return tournamentDecorator;
    }

    public void setTournament(Tournament tournament) {
        this.tournamentDecorator.setTournament(tournament);
    }

    public BorderPane loadMainWindow(){
        FXMLLoader loader = new FXMLLoader(getClass().getResource("mainWindow.fxml"));
        try {
            return loader.load();
        } catch (IOException e) {
            e.printStackTrace();
            //TODO handle and logging
        }
        return null;
    }

    public void loadTournamentList(BorderPane pane, FactoryDecorator factoryDecorator){
        tournamentDecorator.setTournament(null);
        TournamentListController controller = (TournamentListController) setCenterOfBorderPane(pane, getClass().getResource("tournamentList/tournamentList.fxml"), factoryDecorator);
    }

    //Can be used to Open new Scene in same Stage.
    //This way possible to later give object to Controller
    public void loadParticipantFormular(BorderPane pane, FactoryDecorator factoryDecorator) {
        setCenterOfBorderPane(pane, getClass().getResource("participantAddFormular/participantFormular.fxml"), factoryDecorator);
    }

    public void loadPlacesFormular(BorderPane pane, FactoryDecorator factoryDecorator) {
        setCenterOfBorderPane(pane, getClass().getResource("placesAddFormular/PlacesFormular.fxml"), factoryDecorator);
    }

    public void loadGameScheduler(BorderPane pane, FactoryDecorator factoryDecorator) {
        setCenterOfBorderPane(pane, getClass().getResource("gameScheduleView/GameSchedule.fxml"), factoryDecorator);
    }

    public void loadGameView(VBox box, Game game, FactoryDecorator factoryDecorator) {
        try {
            FXMLLoader loader = new FXMLLoader(getClass().getResource("gameScheduleView/Game.fxml"));
            box.getChildren().add(loader.load());
            GameController controller = loader.getController();
            controller.setup(new GameDecorator(game, tournamentDecorator));

        } catch (IOException e) {
            e.printStackTrace();
            //TODO LOGGER
        }
    }

    private FXController setCenterOfBorderPane(BorderPane pane, URL location, FactoryDecorator factoryDecorator) {
        FXController controller = null;
        try {
            FXMLLoader loader = new FXMLLoader(location);
            pane.setCenter(loader.load());
            controller = loader.getController();
            controller.setup(tournamentDecorator, fileIO, factoryDecorator, pane);
            controller.loadContent();
        } catch (IOException e) {
            e.printStackTrace();
            //TODO handle and logging?
        }
        return controller;
    }




}
